@@ -15,6 +15,9 @@ processors = []
 
 
 class BaseArgProcessor:
+    """
+    *Base Argument Processor class in which base methods are defined*
+    """
 
     def __init__(self, arg):
         self._arg = arg
@@ -22,31 +25,56 @@ class BaseArgProcessor:
     @staticmethod
     def interested_in(arg):
         """
-        return: True if arg must be processed by this class False if not.
+        Returns:
+            True if arg must be processed by this class False if not.
         """
+
         raise NotImplementedError()
 
     def process(self, instance):
         """
-        return: Processed argument.
+        Returns:
+            Processed argument.
         """
+
         raise NotImplementedError()
 
 
 class DefaultArgProcessor(BaseArgProcessor):
+    """
+    *A simple Argument Processor which returns the argument itself.*
+    """
 
     @staticmethod
     def interested_in(arg):
+        """
+        Returns:
+            Always True.
+        """
+
         return True
 
     def process(self, instance):
+        """
+        Returns:
+            Argument itself.
+        """
+
         return self._arg
 
 
 class SimpleCallableArgProcessor(BaseArgProcessor):
+    """
+    *An Argument Processor specific for callable without parameters.*
+    """
 
     @staticmethod
     def interested_in(arg):
+        """
+        Returns:
+            True if the argument is a function which not expect any parameters.
+        """
+
         try:
             sig = inspect.signature(arg)
             return len(sig.parameters) == 0
@@ -54,6 +82,11 @@ class SimpleCallableArgProcessor(BaseArgProcessor):
             return False
 
     def process(self, _):
+        """
+        Returns:
+            Argument execution result.
+        """
+
         return self._arg()
 
 
@@ -61,9 +94,17 @@ processors.append(SimpleCallableArgProcessor)
 
 
 class CallableWithSelfArgProcessor(BaseArgProcessor):
+    """
+    *An Argument Processor specific for callable with *self* as unique parameter.*
+    """
 
     @staticmethod
     def interested_in(arg):
+        """
+        Returns:
+            True if the argument is a function which expect only self as unique argument.
+        """
+
         try:
             sig = inspect.signature(arg)
             return len(sig.parameters) == 1 and "self" in sig.parameters
@@ -71,6 +112,11 @@ class CallableWithSelfArgProcessor(BaseArgProcessor):
             return False
 
     def process(self, instance):
+        """
+        Returns:
+            Argument execution result passing RuleFunction instance as argument.
+        """
+
         return self._arg(instance)
 
 
@@ -78,9 +124,17 @@ processors.append(CallableWithSelfArgProcessor)
 
 
 class CallableWithPayloadArgProcessor(BaseArgProcessor):
+    """
+    *An Argument Processor specific for callable with *payload* as unique parameter.*
+    """
 
     @staticmethod
     def interested_in(arg):
+        """
+        Returns:
+            True if the argument is a function which expect only *payload* as unique argument.
+        """
+
         try:
             sig = inspect.signature(arg)
             return len(sig.parameters) == 1 and "payload" in sig.parameters
@@ -88,6 +142,11 @@ class CallableWithPayloadArgProcessor(BaseArgProcessor):
             return False
 
     def process(self, instance):
+        """
+        Returns:
+            Return the argument execution result passing RuleFunction instance payload as argument.
+        """
+
         return self._arg(instance.payload)
 
 
@@ -95,9 +154,17 @@ processors.append(CallableWithPayloadArgProcessor)
 
 
 class CallableWithSubjectArgProcessor(BaseArgProcessor):
+    """
+    *An Argument Processor specific for callable with *subject* as unique parameter.*
+    """
 
     @staticmethod
     def interested_in(arg):
+        """
+        Returns:
+            True if the argument is a function which expect only *subject* as unique argument.
+        """
+
         try:
             sig = inspect.signature(arg)
             return len(sig.parameters) == 1 and "subject" in sig.parameters
@@ -105,9 +172,12 @@ class CallableWithSubjectArgProcessor(BaseArgProcessor):
             return False
 
     def process(self, instance):
+        """
+        Returns:
+            Return the argument execution result passing RuleFunction instance subject as argument.
+        """
+
         return self._arg(instance.subject)
 
 
 processors.append(CallableWithSubjectArgProcessor)
-
-
